@@ -537,7 +537,7 @@ GType  bd_nvme_sanitize_log_get_type () {
 }
 
 static const gchar * bd_nvme_self_test_result_to_string_stub (BDNVMESelfTestResult result G_GNUC_UNUSED, GError **error) {
-    g_critical ("The function 'bd_nvme_self_test_result_to_string' called, but not implemented!");
+    bd_utils_log_format (BD_UTILS_LOG_CRIT, "The function 'bd_nvme_self_test_result_to_string' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_nvme_self_test_result_to_string' called, but not implemented!");
     return NULL;
@@ -559,7 +559,7 @@ const gchar * bd_nvme_self_test_result_to_string (BDNVMESelfTestResult result, G
 
 
 static BDNVMEControllerInfo * bd_nvme_get_controller_info_stub (const gchar *device G_GNUC_UNUSED, GError **error) {
-    g_critical ("The function 'bd_nvme_get_controller_info' called, but not implemented!");
+    bd_utils_log_format (BD_UTILS_LOG_CRIT, "The function 'bd_nvme_get_controller_info' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_nvme_get_controller_info' called, but not implemented!");
     return NULL;
@@ -585,7 +585,7 @@ BDNVMEControllerInfo * bd_nvme_get_controller_info (const gchar *device, GError
 
 
 static BDNVMENamespaceInfo * bd_nvme_get_namespace_info_stub (const gchar *device G_GNUC_UNUSED, GError **error) {
-    g_critical ("The function 'bd_nvme_get_namespace_info' called, but not implemented!");
+    bd_utils_log_format (BD_UTILS_LOG_CRIT, "The function 'bd_nvme_get_namespace_info' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_nvme_get_namespace_info' called, but not implemented!");
     return NULL;
@@ -611,7 +611,7 @@ BDNVMENamespaceInfo * bd_nvme_get_namespace_info (const gchar *device, GError **
 
 
 static BDNVMESmartLog * bd_nvme_get_smart_log_stub (const gchar *device G_GNUC_UNUSED, GError **error) {
-    g_critical ("The function 'bd_nvme_get_smart_log' called, but not implemented!");
+    bd_utils_log_format (BD_UTILS_LOG_CRIT, "The function 'bd_nvme_get_smart_log' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_nvme_get_smart_log' called, but not implemented!");
     return NULL;
@@ -637,7 +637,7 @@ BDNVMESmartLog * bd_nvme_get_smart_log (const gchar *device, GError **error) {
 
 
 static BDNVMEErrorLogEntry ** bd_nvme_get_error_log_entries_stub (const gchar *device G_GNUC_UNUSED, GError **error) {
-    g_critical ("The function 'bd_nvme_get_error_log_entries' called, but not implemented!");
+    bd_utils_log_format (BD_UTILS_LOG_CRIT, "The function 'bd_nvme_get_error_log_entries' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_nvme_get_error_log_entries' called, but not implemented!");
     return NULL;
@@ -669,7 +669,7 @@ BDNVMEErrorLogEntry ** bd_nvme_get_error_log_entries (const gchar *device, GErro
 
 
 static BDNVMESelfTestLog * bd_nvme_get_self_test_log_stub (const gchar *device G_GNUC_UNUSED, GError **error) {
-    g_critical ("The function 'bd_nvme_get_self_test_log' called, but not implemented!");
+    bd_utils_log_format (BD_UTILS_LOG_CRIT, "The function 'bd_nvme_get_self_test_log' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_nvme_get_self_test_log' called, but not implemented!");
     return NULL;
@@ -696,7 +696,7 @@ BDNVMESelfTestLog * bd_nvme_get_self_test_log (const gchar *device, GError **err
 
 
 static BDNVMESanitizeLog * bd_nvme_get_sanitize_log_stub (const gchar *device G_GNUC_UNUSED, GError **error) {
-    g_critical ("The function 'bd_nvme_get_sanitize_log' called, but not implemented!");
+    bd_utils_log_format (BD_UTILS_LOG_CRIT, "The function 'bd_nvme_get_sanitize_log' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_nvme_get_sanitize_log' called, but not implemented!");
     return NULL;
@@ -726,7 +726,7 @@ BDNVMESanitizeLog * bd_nvme_get_sanitize_log (const gchar *device, GError **erro
 
 
 static gboolean  bd_nvme_device_self_test_stub (const gchar *device G_GNUC_UNUSED, BDNVMESelfTestAction action G_GNUC_UNUSED, GError **error) {
-    g_critical ("The function 'bd_nvme_device_self_test' called, but not implemented!");
+    bd_utils_log_format (BD_UTILS_LOG_CRIT, "The function 'bd_nvme_device_self_test' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_nvme_device_self_test' called, but not implemented!");
     return FALSE;
@@ -759,7 +759,7 @@ gboolean  bd_nvme_device_self_test (const gchar *device, BDNVMESelfTestAction ac
 
 
 static gboolean  bd_nvme_format_stub (const gchar *device G_GNUC_UNUSED, guint16 lba_data_size G_GNUC_UNUSED, guint16 metadata_size G_GNUC_UNUSED, BDNVMEFormatSecureErase secure_erase G_GNUC_UNUSED, GError **error) {
-    g_critical ("The function 'bd_nvme_format' called, but not implemented!");
+    bd_utils_log_format (BD_UTILS_LOG_CRIT, "The function 'bd_nvme_format' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_nvme_format' called, but not implemented!");
     return FALSE;
@@ -803,7 +803,7 @@ gboolean  bd_nvme_format (const gchar *device, guint16 lba_data_size, guint16 me
 
 
 static gboolean  bd_nvme_sanitize_stub (const gchar *device G_GNUC_UNUSED, BDNVMESanitizeAction action G_GNUC_UNUSED, gboolean no_dealloc G_GNUC_UNUSED, gint overwrite_pass_count G_GNUC_UNUSED, guint32 overwrite_pattern G_GNUC_UNUSED, gboolean overwrite_invert_pattern G_GNUC_UNUSED, GError **error) {
-    g_critical ("The function 'bd_nvme_sanitize' called, but not implemented!");
+    bd_utils_log_format (BD_UTILS_LOG_CRIT, "The function 'bd_nvme_sanitize' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_nvme_sanitize' called, but not implemented!");
     return FALSE;
@@ -861,7 +861,7 @@ gboolean  bd_nvme_sanitize (const gchar *device, BDNVMESanitizeAction action, gb
 
 
 static gchar * bd_nvme_get_host_nqn_stub (GError **error) {
-    g_critical ("The function 'bd_nvme_get_host_nqn' called, but not implemented!");
+    bd_utils_log_format (BD_UTILS_LOG_CRIT, "The function 'bd_nvme_get_host_nqn' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_nvme_get_host_nqn' called, but not implemented!");
     return NULL;
@@ -886,7 +886,7 @@ gchar * bd_nvme_get_host_nqn (GError **error) {
 
 
 static gchar * bd_nvme_generate_host_nqn_stub (GError **error) {
-    g_critical ("The function 'bd_nvme_generate_host_nqn' called, but not implemented!");
+    bd_utils_log_format (BD_UTILS_LOG_CRIT, "The function 'bd_nvme_generate_host_nqn' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_nvme_generate_host_nqn' called, but not implemented!");
     return NULL;
@@ -912,7 +912,7 @@ gchar * bd_nvme_generate_host_nqn (GError **error) {
 
 
 static gchar * bd_nvme_get_host_id_stub (GError **error) {
-    g_critical ("The function 'bd_nvme_get_host_id' called, but not implemented!");
+    bd_utils_log_format (BD_UTILS_LOG_CRIT, "The function 'bd_nvme_get_host_id' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_nvme_get_host_id' called, but not implemented!");
     return NULL;
@@ -937,7 +937,7 @@ gchar * bd_nvme_get_host_id (GError **error) {
 
 
 static gboolean  bd_nvme_set_host_nqn_stub (const gchar *host_nqn G_GNUC_UNUSED, GError **error) {
-    g_critical ("The function 'bd_nvme_set_host_nqn' called, but not implemented!");
+    bd_utils_log_format (BD_UTILS_LOG_CRIT, "The function 'bd_nvme_set_host_nqn' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_nvme_set_host_nqn' called, but not implemented!");
     return FALSE;
@@ -963,7 +963,7 @@ gboolean  bd_nvme_set_host_nqn (const gchar *host_nqn, GError **error) {
 
 
 static gboolean  bd_nvme_set_host_id_stub (const gchar *host_id G_GNUC_UNUSED, GError **error) {
-    g_critical ("The function 'bd_nvme_set_host_id' called, but not implemented!");
+    bd_utils_log_format (BD_UTILS_LOG_CRIT, "The function 'bd_nvme_set_host_id' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_nvme_set_host_id' called, but not implemented!");
     return FALSE;
@@ -989,7 +989,7 @@ gboolean  bd_nvme_set_host_id (const gchar *host_id, GError **error) {
 
 
 static gboolean  bd_nvme_connect_stub (const gchar *subsysnqn G_GNUC_UNUSED, const gchar *transport G_GNUC_UNUSED, const gchar *transport_addr G_GNUC_UNUSED, const gchar *transport_svcid G_GNUC_UNUSED, const gchar *host_traddr G_GNUC_UNUSED, const gchar *host_iface G_GNUC_UNUSED, const gchar *host_nqn G_GNUC_UNUSED, const gchar *host_id G_GNUC_UNUSED, const BDExtraArg **extra G_GNUC_UNUSED, GError **error) {
-    g_critical ("The function 'bd_nvme_connect' called, but not implemented!");
+    bd_utils_log_format (BD_UTILS_LOG_CRIT, "The function 'bd_nvme_connect' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_nvme_connect' called, but not implemented!");
     return FALSE;
@@ -1067,7 +1067,7 @@ gboolean  bd_nvme_connect (const gchar *subsysnqn, const gchar *transport, const
 
 
 static gboolean  bd_nvme_disconnect_stub (const gchar *subsysnqn G_GNUC_UNUSED, GError **error) {
-    g_critical ("The function 'bd_nvme_disconnect' called, but not implemented!");
+    bd_utils_log_format (BD_UTILS_LOG_CRIT, "The function 'bd_nvme_disconnect' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_nvme_disconnect' called, but not implemented!");
     return FALSE;
@@ -1095,7 +1095,7 @@ gboolean  bd_nvme_disconnect (const gchar *subsysnqn, GError **error) {
 
 
 static gboolean  bd_nvme_disconnect_by_path_stub (const gchar *path G_GNUC_UNUSED, GError **error) {
-    g_critical ("The function 'bd_nvme_disconnect_by_path' called, but not implemented!");
+    bd_utils_log_format (BD_UTILS_LOG_CRIT, "The function 'bd_nvme_disconnect_by_path' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_nvme_disconnect_by_path' called, but not implemented!");
     return FALSE;
@@ -1122,7 +1122,7 @@ gboolean  bd_nvme_disconnect_by_path (const gchar *path, GError **error) {
 
 
 static gchar ** bd_nvme_find_ctrls_for_ns_stub (const gchar *ns_sysfs_path G_GNUC_UNUSED, const gchar *subsysnqn G_GNUC_UNUSED, const gchar *host_nqn G_GNUC_UNUSED, const gchar *host_id G_GNUC_UNUSED, GError **error) {
-    g_critical ("The function 'bd_nvme_find_ctrls_for_ns' called, but not implemented!");
+    bd_utils_log_format (BD_UTILS_LOG_CRIT, "The function 'bd_nvme_find_ctrls_for_ns' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_nvme_find_ctrls_for_ns' called, but not implemented!");
     return NULL;
