@@ -36,9 +36,7 @@ class LVMTestCase(unittest.TestCase):
 
     @classmethod
     def setUpClass(cls):
-        ps = BlockDev.PluginSpec()
-        ps.name = BlockDev.Plugin.LVM
-        ps.so_name = "libbd_lvm.so.3"
+        ps = BlockDev.PluginSpec(name=BlockDev.Plugin.LVM, so_name="libbd_lvm.so.3")
         cls.requested_plugins = [ps]
 
         if not BlockDev.is_initialized():
